@@ -14,6 +14,14 @@ import requests
 from dateutil.relativedelta import relativedelta  # 安装 pip install python-dateutil
 from retrying import retry
 
+def time_stamp(many=13):
+    """
+    返回指定位数时间戳
+    :param many: 默认13位
+    :return:
+    """
+    ts = str(int(time.time()*10000000))[:many]
+    return ts
 
 def datetime_toStr(dt: datetime, fm: str = "%Y-%m-%d") -> str:
     """
@@ -436,4 +444,10 @@ if __name__ == '__main__':
     # print(now_time)
     # flag = judge_time(now_time, "02:00:00", "05:00:00", year=False)
     # print(flag)
-    print(split_time_h("2022-03-05 16:41:50", "2022-03-13 16:41:50"))
+    # print(split_time_h("2022-03-05 16:41:50", "2022-03-13 16:41:50"))
+    print(time_stamp())
+    print(time_stamp(1))
+    print(time_stamp(2))
+    print(time_stamp(3))
+    print(time_stamp(4))
+    print(time_stamp(5))
